@@ -1,15 +1,14 @@
-#' @importFrom utils read.csv read.table tail write.table
-#' @importFrom rgdal readOGR
-#' @importFrom rgdal writeOGR
-#' @importFrom ggplot2 fortify
-#' @importFrom methods as
 #' @import     dplyr
+#' @import     sf
 #' @import     sp
+#' @importFrom methods as
+#' @importFrom rlang .data
+#' @importFrom utils read.csv read.table tail write.table
 #' @useDynLib  dggridR
 
 
 #' @name dg_env
-#' 
+#'
 #' @title Control global aspects of the dggridR package
 #'
 #' @description
@@ -21,7 +20,7 @@ dg_env <- new.env()
 assign("dg_debug", FALSE, envir=dg_env)
 
 #' @name dg_shpfname_south_africa
-#' 
+#'
 #' @title National border of South Africa
 #'
 #' @description
@@ -38,12 +37,12 @@ dg_shpfname_south_africa <- function(){
 
 
 #' @name dgconstruct
-#' 
+#'
 #' @title      Construct a discrete global grid system (dggs) object
 #'
 #' @description
 #'             Construct a discrete global grid system (dggs) object
-#' 
+#'
 #' @param projection Type of grid to use. Options are: ISEA and FULLER.
 #'                   Default: ISEA3H
 #'
@@ -51,7 +50,7 @@ dg_shpfname_south_africa <- function(){
 #'                   Default: HEXAGON
 #'
 #' @param aperture   How finely subsequent resolution levels divide the grid.
-#'                   Options are: 3, 4. Not all options work with all 
+#'                   Options are: 3, 4. Not all options work with all
 #'                   projections and topologies.
 #'                   Default: 3
 #'
@@ -93,12 +92,12 @@ dg_shpfname_south_africa <- function(){
 #' @return          Returns a dggs object which can be passed to other dggridR
 #'                  functions
 #'
-#' @examples 
+#' @examples
 #' library(dggridR)
 #' dggs <- dgconstruct(res=20)
 #'
 #' dggs <- dgconstruct(area=5,metric=FALSE)
-#' @export 
+#' @export
 dgconstruct <- function(
   projection   = 'ISEA',
   aperture     = 3,
@@ -149,7 +148,7 @@ dgconstruct <- function(
 
 
 #' @name dgsetres
-#' 
+#'
 #' @title Set the resolution of a dggs object
 #'
 #' @description
@@ -167,11 +166,11 @@ dgconstruct <- function(
 #' @return     Returns a dggs object which can be passed to other dggridR
 #'             functions
 #'
-#' @examples 
+#' @examples
 #' library(dggridR)
 #' dggs <- dgconstruct(res=20)
 #' dggs <- dgsetres(dggs,10)
-#' @export 
+#' @export
 dgsetres <- function(dggs,res){
   dggs[['res']] = res
   dgverify(dggs)
@@ -181,12 +180,12 @@ dgsetres <- function(dggs,res){
 
 
 #' @name dgverify
-#' 
+#'
 #' @title Verify that a dggs object has appropriate values
 #'
 #' @description
 #'             Verify that a dggs object has appropriate values
-#' 
+#'
 #' @param dggs The dggs object to be verified
 #'
 #' @return     The function has no return value. A stop signal is raised if the
@@ -220,62 +219,23 @@ dgverify <- function(dggs){
 
 
 
-#' @name dgtransform
-#' 
-#' @title (DEPRECATED) Converts lat-long pairs into discrete global grid cell numbers
-#'
-#' @description
-#'          A discrete global grid maps lat-long points to particular cells.
-#'          These cells are uniquely numbered, for a given resolution, from
-#'          1 to some maximum number. Cell numbers may be reused from one
-#'          resolution to the next.
-#'          THIS FUNCTION IS DEPRECATED.
-#' 
-#' @param dggs A dggs object from dgconstruct().
-#'
-#' @param lat  A vector of latitudes. Same length at the longtiudes
-#'
-#' @param lon  A vector of longitudes. Same length as the latitudes.
-#'
-#' @return     A vector of the same length as latitudes and longitudes 
-#'             containing the cell id numbers of the points' cells
-#'             in the discrete grid.
-#'
-#' @examples 
-#' library(dggridR)
-#' data(dgquakes)
-#'
-#' #Construct a grid with cells about ~1000 miles wide
-#' dggs          <- dgconstruct(spacing=1000,metric=FALSE) 
-#' dgquakes$cell <- dgtransform(dggs,dgquakes$lat,dgquakes$lon)
-#' @export 
-dgtransform <- function(dggs, lat, lon){ #TODO: Make sure we're not modifying the original dggs
-  dgverify(dggs)
-
-  warning("The 'dgtransform(dggs,lat,lon)' function has been deprecated. Please use 'dgGEO_to_SEQNUM(dggs,lon,lat)' instead! NOTE THE ARGUMENT ORDER!")
-
-  dgGEO_to_SEQNUM(dggs, lon, lat)$seqnum
-}
-
-
-
 #' @name dginfo
-#' 
-#' @title Print a buncha info about a dggs object to the screen
+#'
+#' @title Print info about a dggs object to the screen
 #'
 #' @description
 #'          dggs objects have many settings. This returns all of them, along
 #'          with info about the grid being specified.
-#' 
+#'
 #' @param dggs A dggs object from dgconstruct()
 #'
 #' @return No return. All info is printed to the screen.
 #'
-#' @examples 
+#' @examples
 #' library(dggridR)
 #' dggs <- dgconstruct(res=20)
 #' dginfo(dggs)
-#' @export 
+#' @export
 dginfo <- function(dggs){
   dgverify(dggs)
 
@@ -294,23 +254,23 @@ dginfo <- function(dggs){
 
 
 #' @name dggetres
-#' 
+#'
 #' @title      Get table of grid resolution information
 #'
 #' @description
 #'             Gets a grid's resolution and cell property info as a data frame.
-#' 
+#'
 #' @param dggs A dggs object from dgconstruct()
 #'
 #' @return     A data frame containing the resolution levels, number of cells,
 #'             area of those cells, intercell spacing, and characteristic length
 #'             scale of the cells. All values are in kilometres.
 #'
-#' @examples 
+#' @examples
 #' library(dggridR)
 #' dggs <- dgconstruct(res=20)
 #' dggetres(dggs)
-#' @export 
+#' @export
 dggetres <- function(dggs){
   dgverify(dggs)
 
@@ -328,13 +288,13 @@ dggetres <- function(dggs){
 
 
 #' @name dgmaxcell
-#' 
+#'
 #' @title      Get largest cell id for a dggs
 #'
 #' @description
 #'             Cells are labeled 1-N. This function returns N. This is useful if
 #'             you want to choose cells from the dggs randomly.
-#' 
+#'
 #' @param dggs A dggs object from dgconstruct()
 #'
 #' @param res  If NA, use the resolution specified by the dggs. Otherwise,
@@ -342,15 +302,15 @@ dggetres <- function(dggs){
 #'
 #' @return     The maximum cell id.
 #'
-#' @examples 
+#' @examples
 #' #Choose a set of cells randomly distributed over the Earth
 #' library(dggridR)
 #' dggs    <- dgconstruct(spacing=1000, metric=FALSE, resround='down')
 #' N       <- 100                                 #Number of cells
 #' maxcell <- dgmaxcell(dggs)                     #Get maximum cell id
 #' cells   <- sample(1:maxcell, N, replace=FALSE) #Choose random cells
-#' grid    <- dgcellstogrid(dggs,cells,frame=TRUE,wrapcells=TRUE) #Get grid
-#' @export 
+#' grid    <- dgcellstogrid(dggs,cells) #Get grid
+#' @export
 dgmaxcell <- function(dggs,res=NA){
   dgverify(dggs)
 
@@ -361,13 +321,13 @@ dgmaxcell <- function(dggs,res=NA){
     restoget <- res
 
   #Add one because R uses 1-based indexing and there is a row 0
-  reses$cells[restoget+1] 
+  reses$cells[restoget+1]
 }
 
 
 
 #' @name dg_closest_res
-#' 
+#'
 #' @title Determine an appropriate grid resolution based on input data.
 #'
 #' @description
@@ -378,7 +338,7 @@ dgmaxcell <- function(dggs,res=NA){
 #'
 #' @param dggs      A dggs object from dgconstruct()
 #'
-#' @param col       Column in which to search for a close value. Should be: 
+#' @param col       Column in which to search for a close value. Should be:
 #'                  area_km, spacing_km, or cls_km.
 #'
 #' @param val       The value to search for
@@ -392,7 +352,7 @@ dgmaxcell <- function(dggs,res=NA){
 #'
 #' @return A number representing the grid resolution
 #'
-#' @examples 
+#' @examples
 #' library(dggridR)
 #' dggs <- dgconstruct(res=20)
 #' res  <- dg_closest_res(dggs,'area_km',1)
@@ -435,11 +395,11 @@ dg_closest_res <- function(dggs,col,val,round='nearest',show_info=TRUE,metric=TR
 
 
 #' @name dg_closest_res_to_area
-#' 
+#'
 #' @title           Determine resolution based on desired area
 #'
 #' @description
-#'                  Determine an appropriate grid resolution based on a desired 
+#'                  Determine an appropriate grid resolution based on a desired
 #'                  cell area.
 #'
 #' @param dggs      A dggs object from dgconstruct()
@@ -455,12 +415,12 @@ dg_closest_res <- function(dggs,col,val,round='nearest',show_info=TRUE,metric=TR
 #'
 #' @return A number representing the grid resolution
 #'
-#' @examples 
+#' @examples
 #' library(dggridR)
 #' dggs <- dgconstruct(res=20)
 #' res  <- dg_closest_res_to_area(dggs,1)
 #' dggs <- dgsetres(dggs,res)
-#' @export 
+#' @export
 dg_closest_res_to_area <- function(dggs,area,round='nearest',show_info=TRUE,metric=TRUE){
   dg_closest_res(dggs,'area_km',area,round,show_info,metric)
 }
@@ -468,10 +428,10 @@ dg_closest_res_to_area <- function(dggs,area,round='nearest',show_info=TRUE,metr
 
 
 #' @name dg_closest_res_to_spacing
-#' 
+#'
 #' @title           Determine grid resolution from desired spacing.
 #'
-#' @description     Determine an appropriate grid resolution based on a desired 
+#' @description     Determine an appropriate grid resolution based on a desired
 #'                  spacing between the center of adjacent cells.
 #'
 #' @param dggs      A dggs object from dgconstruct()
@@ -487,12 +447,12 @@ dg_closest_res_to_area <- function(dggs,area,round='nearest',show_info=TRUE,metr
 #'
 #' @return A number representing the grid resolution
 #'
-#' @examples 
+#' @examples
 #' library(dggridR)
 #' dggs <- dgconstruct(res=20)
 #' res  <- dg_closest_res_to_spacing(dggs,1)
 #' dggs <- dgsetres(dggs,res)
-#' @export 
+#' @export
 dg_closest_res_to_spacing <- function(dggs,spacing,round='nearest',show_info=TRUE,metric=TRUE){
   dg_closest_res(dggs,'spacing_km',spacing,round,show_info,metric)
 }
@@ -500,8 +460,8 @@ dg_closest_res_to_spacing <- function(dggs,spacing,round='nearest',show_info=TRU
 
 
 #' @name dg_closest_res_to_cls
-#' 
-#' @title Determine an appropriate grid resolution based on a desired 
+#'
+#' @title Determine an appropriate grid resolution based on a desired
 #'        characteristic length scale of the cells.
 #'
 #' @description
@@ -521,7 +481,7 @@ dg_closest_res_to_spacing <- function(dggs,spacing,round='nearest',show_info=TRU
 #'
 #' @return A number representing the grid resolution
 #'
-#' @examples 
+#' @examples
 #' library(dggridR)
 #' dggs <- dgconstruct(res=20)
 #' res  <- dg_closest_res_to_cls(dggs,1)
@@ -534,7 +494,7 @@ dg_closest_res_to_cls <- function(dggs,cls,round='nearest',show_info=TRUE,metric
 
 
 #' @name dg_process_polydata
-#' 
+#'
 #' @title   Load a KML file
 #'
 #' @description     Convert data from internal dggrid functions into something
@@ -542,58 +502,22 @@ dg_closest_res_to_cls <- function(dggs,cls,round='nearest',show_info=TRUE,metric
 #'
 #' @param polydata  Polygons generated by dggrid. These will be converted.
 #'
-#' @param frame     If TRUE, return a data frame suitable for ggplot plotting.
-#'                  If FALSE, return an SpatialPolygons
+#' @return Returns an sf object.
 #'
-#' @param wrapcells Cells which cross -180/180 degrees can present 
-#'                  difficulties for plotting. Setting this TRUE will result in
-#'                  cells with components in both hemispheres to be mapped
-#'                  entirely to positive degrees (the Eastern hemisphere). As a
-#'                  result, such cells will have components in the range
-#'                  [180,360). Only used when \code{frame=TRUE}.
-#'
-#' @return Returns a data frame or OGR poly object, as specified by \code{frame}
-#'
-dg_process_polydata <- function(polydata,frame,wrapcells){
-  polydata  <- as.data.frame(polydata)
-  polydata  <- split(polydata, polydata$seqnum)
-  an        <- names(polydata)
-  polydata  <- lapply(polydata, function(x) { x["seqnum"] <- NULL; x })
-  polydata  <- lapply(polydata, Polygon)
-  polydata  <- lapply(seq_along(polydata), function(i) Polygons(list(polydata[[i]]), ID = an[i]  ))
-  polydata  <- SpatialPolygons(polydata, proj4string = CRS("+proj=longlat +datum=WGS84") )
+dg_process_polydata <- function(polydata){
+  polydata <- as.data.frame(polydata)
 
-  #These two lines suppress a WARNING message that would otherwise be raised by
-  #`R CMD check` due to the use of dplyr
-  long  <- NULL
-  group <- NULL
-
-  if(frame){
-    polydata.points      <- fortify(polydata, region="seqnum")
-    polydata.points$cell <- polydata.points$id
-    polydata.points$id   <- NULL
-
-    if(wrapcells){
-      #Find dangerous polygons based on how many degrees of longitude they span
-      groups_to_wrap <- polydata.points %>% group_by(group) %>% summarise(diff=max(long)-min(long)) %>% filter(diff>180) %>% select(group)
-
-      #Adjust them so they appear on the eastern side of the map
-      polydata.points <- polydata.points %>% mutate(long=ifelse(group %in% groups_to_wrap$group, ifelse(long<0,long+360,long), long))
-    }
-
-    #Arrange polygon points so they are ordered appropriately, otherwise the results
-    #will not be nice, closed cells, but weird triangular thingies
-    polydata.points %>% arrange(group,order)
-
-  } else {
-    polydata
-  }
+  polydata %>%
+    sf::st_as_sf(coords=c("x", "y"), crs=4326) %>%
+    group_by(.data$seqnum) %>%
+    summarise(geometry = sf::st_combine(geometry)) %>%
+    sf::st_cast("POLYGON")
 }
 
 
 
 #' @name dgrectgrid
-#' 
+#'
 #' @title   Return the coordinates constituting the boundary of cells within a
 #'          specified region
 #'
@@ -611,39 +535,29 @@ dg_process_polydata <- function(polydata,frame,wrapcells){
 #'
 #' @param maxlon    Maximum longitude of region of interest
 #'
-#' @param frame     If TRUE, return a data frame suitable for ggplot plotting.
-#'                  If FALSE, return an OGR poly object
-#'
-#' @param wrapcells Cells which cross -180/180 degrees can present 
-#'                  difficulties for plotting. Setting this TRUE will result in
-#'                  cells with components in both hemispheres to be mapped
-#'                  entirely to positive degrees (the Eastern hemisphere). As a
-#'                  result, such cells will have components in the range
-#'                  [180,360). Only used when \code{frame=TRUE}.
-#'
 #' @param cellsize  Distance, in degrees, between the sample points used to
 #'                  generate the grid. Small values yield long generation times
 #'                  while large values may omit cells.
 #'
-#' @param savegrid  If savegrid is set to a file path, then a shapefile 
+#' @param savegrid  If savegrid is set to a file path, then a shapefile
 #'                  containing the grid is written to that path and the filename
 #'                  is returned. No other manipulations are done.
 #'                  Default: NA (do not save grid, return it)
 #'
-#' @return Returns a data frame or OGR poly object, as specified by \code{frame}.
+#' @return Returns an sf object.
 #'         If \code{!is.na(savegrid)}, returns a filename.
 #'
-#' @examples 
+#' @examples
 #' library(dggridR)
 #' dggs <- dgconstruct(spacing=1000,metric=FALSE,resround='down')
 #'
 #' #Get grid cells for the conterminous United States
 #' grid <- dgrectgrid(dggs,
-#'                minlat=24.7433195, minlon=-124.7844079, 
-#'                maxlat=49.3457868, maxlon=-66.9513812, frame=TRUE)
+#'                minlat=24.7433195, minlon=-124.7844079,
+#'                maxlat=49.3457868, maxlon=-66.9513812)
 #' @export
-dgrectgrid <- function(dggs,minlat=-1,minlon=-1,maxlat=-1,maxlon=-1,cellsize=0.1,frame=TRUE,wrapcells=TRUE,savegrid=NA){ #TODO: Densify?
-  dgverify(dggs) 
+dgrectgrid <- function(dggs,minlat=-1,minlon=-1,maxlat=-1,maxlon=-1,cellsize=0.1,savegrid=NA){ #TODO: Densify?
+  dgverify(dggs)
 
   coords <- matrix(c(minlon, minlat, maxlon, minlat, maxlon, maxlat, maxlon, minlat, minlon, minlat), ncol = 2, byrow = TRUE)
   regbox <- Polygon(coords)
@@ -655,56 +569,46 @@ dgrectgrid <- function(dggs,minlat=-1,minlon=-1,maxlat=-1,maxlon=-1,cellsize=0.1
   #Convert the points to SEQNUM ids for dggs
   samp_points <- dgGEO_to_SEQNUM(dggs,samp_points$x1, samp_points$x2)$seqnum
 
-  dgcellstogrid(dggs, samp_points, frame=frame, wrapcells=wrapcells, savegrid=savegrid)
+  dgcellstogrid(dggs, samp_points, savegrid=savegrid)
 }
 
 
 
 #' @name dgearthgrid
-#' 
+#'
 #' @title   Return the coordinates constituting the boundary of cells for the
 #'          entire Earth
 #'
 #' @description     Note: If you have a high-resolution grid this may take a
-#'                  loooooong time to execute.
+#'                  very long time to execute.
 #'
 #' @param dggs      A dggs object from dgconstruct()
 #'
-#' @param frame     If TRUE, return a data frame suitable for ggplot plotting.
-#'                  If FALSE, return an OGR poly object
-#'
-#' @param wrapcells Cells which cross -180/180 degrees can present 
-#'                  difficulties for plotting. Setting this TRUE will result in
-#'                  cells with components in both hemispheres to be mapped
-#'                  entirely to positive degrees (the Eastern hemisphere). As a
-#'                  result, such cells will have components in the range
-#'                  [180,360). Only used when \code{frame=TRUE}.
-#'
-#' @param savegrid  If savegrid is set to a file path, then a shapefile 
+#' @param savegrid  If savegrid is set to a file path, then a shapefile
 #'                  containing the grid is written to that path and the filename
 #'                  is returned. No other manipulations are done.
 #'                  Default: NA (do not save grid, return it)
 #'
-#' @return Returns a data frame or OGR poly object, as specified by \code{frame}.
+#' @return Returns an sf object.
 #'         If \code{!is.na(savegrid)}, returns a filename.
 #'
-#' @examples 
+#' @examples
 #' \donttest{
 #' library(dggridR)
 #' dggs         <- dgconstruct(res=20)
 #' res          <- dg_closest_res_to_spacing(dggs,spacing=1000,round='down',metric=FALSE)
 #' dggs         <- dgsetres(dggs,res)
-#' gridfilename <- dgearthgrid(dggs,savegrid="temp.shp") #Save directly to a file
+#' gridfilename <- dgearthgrid(dggs,savegrid=tempfile(fileext=".shp")) #Save directly to a file
 #' }
 #' @export
-dgearthgrid <- function(dggs,frame=TRUE,wrapcells=TRUE,savegrid=NA){ #TODO: Densify?
-  dgverify(dggs) 
+dgearthgrid <- function(dggs,savegrid=NA){ #TODO: Densify?
+  dgverify(dggs)
 
   grid <- GlobalGrid(dggs[["pole_lon_deg"]], dggs[["pole_lat_deg"]], dggs[["azimuth_deg"]], dggs[["aperture"]], dggs[["res"]], dggs[["topology"]], dggs[["projection"]])
   if(is.na(savegrid)){
-    dg_process_polydata(grid,frame,wrapcells)
+    dg_process_polydata(grid)
   } else {
-    grid <- dg_process_polydata(grid,frame=FALSE,wrapcells=FALSE)
+    grid <- dg_process_polydata(grid)
     dgsavegrid(grid,savegrid)
   }
 }
@@ -712,10 +616,10 @@ dgearthgrid <- function(dggs,frame=TRUE,wrapcells=TRUE,savegrid=NA){ #TODO: Dens
 
 
 #' @name dgcellstogrid
-#' 
+#'
 #' @title           Return boundary coordinates for specified cells
 #'
-#' @description     Returns the coordinates constituting the boundary of a 
+#' @description     Returns the coordinates constituting the boundary of a
 #'                  specified set of cells. Duplicates are eliminated to reduce
 #'                  processing and storage requirements.
 #'
@@ -723,37 +627,27 @@ dgearthgrid <- function(dggs,frame=TRUE,wrapcells=TRUE,savegrid=NA){ #TODO: Dens
 #'
 #' @param cells     The cells to get the boundaries of
 #'
-#' @param frame     If TRUE, return a data frame suitable for ggplot plotting.
-#'                  If FALSE, return an OGR poly object
-#'
-#' @param wrapcells Cells which cross -180/180 degrees can present 
-#'                  difficulties for plotting. Setting this TRUE will result in
-#'                  cells with components in both hemispheres to be mapped
-#'                  entirely to positive degrees (the Eastern hemisphere). As a
-#'                  result, such cells will have components in the range
-#'                  [180,360). Only used when \code{frame=TRUE}.
-#'
-#' @param savegrid  If savegrid is set to a file path, then a shapefile 
+#' @param savegrid  If savegrid is set to a file path, then a shapefile
 #'                  containing the grid is written to that path and the filename
 #'                  is returned. No other manipulations are done.
 #'                  Default: NA (do not save grid, return it)
 #'
-#' @return Returns a data frame or OGR poly object, as specified by \code{frame}.
+#' @return Returns an sf object.
 #'         If \code{!is.na(savegrid)}, returns a filename.
 #'
-#' @examples 
+#' @examples
 #' library(dggridR)
 #' data(dgquakes)
 #'
 #' #Construct a grid with cells about ~1000 miles wide
-#' dggs          <- dgconstruct(spacing=1000,metric=FALSE) 
-#' dgquakes$cell <- dgtransform(dggs,dgquakes$lat,dgquakes$lon)
+#' dggs          <- dgconstruct(spacing=1000,metric=FALSE)
+#' dgquakes$cell <- dgGEO_to_SEQNUM(dggs,dgquakes$lat,dgquakes$lon)$seqnum
 #'
 #' #Get grid cells for the earthquakes identified
-#' grid          <- dgcellstogrid(dggs, dgquakes$cell, frame=TRUE)
+#' grid          <- dgcellstogrid(dggs, dgquakes$cell)
 #' @export
-dgcellstogrid <- function(dggs,cells,frame=TRUE,wrapcells=TRUE,savegrid=NA){ #TODO: Densify?
-  dgverify(dggs) 
+dgcellstogrid <- function(dggs, cells, savegrid=NA){ #TODO: Densify?
+  dgverify(dggs)
 
   #dggrid also eliminates duplicate cells, but doing so here saves disk space
   #and likely wall time, given the costs of IO, not that it matters unless the
@@ -765,9 +659,9 @@ dgcellstogrid <- function(dggs,cells,frame=TRUE,wrapcells=TRUE,savegrid=NA){ #TO
 
   grid <- SeqNumGrid(dggs[["pole_lon_deg"]], dggs[["pole_lat_deg"]], dggs[["azimuth_deg"]], dggs[["aperture"]], dggs[["res"]], dggs[["topology"]], dggs[["projection"]], cells)
   if(is.na(savegrid)){
-    dg_process_polydata(grid,frame,wrapcells)
+    dg_process_polydata(grid)
   } else {
-    grid <- dg_process_polydata(grid,frame=FALSE,wrapcells=FALSE)
+    grid <- dg_process_polydata(grid)
     dgsavegrid(grid,savegrid)
   }
 }
@@ -785,19 +679,18 @@ dgcellstogrid <- function(dggs,cells,frame=TRUE,wrapcells=TRUE,savegrid=NA){ #TO
 #'
 #' @return          The filename the grid was saved to
 dgsavegrid <- function(grid,shpfname) {
-  grid<-as(grid, "SpatialPolygonsDataFrame")
-  writeOGR(grid, shpfname, driver='ESRI Shapefile', layer='dggrid')
+  sf::write_sf(grid, shpfname, driver='ESRI Shapefile', layer='dggrid')
   shpfname
 }
 
 
 
 #' @name dgshptogrid
-#' 
-#' @title           Return boundary coordinates for cells intersecting a 
+#'
+#' @title           Return boundary coordinates for cells intersecting a
 #'                  shapefile
 #'
-#' @description     Returns the coordinates constituting the boundary of a 
+#' @description     Returns the coordinates constituting the boundary of a
 #'                  set of cells which intersect or are contained by a polygon
 #'                  (or polygons) specified in a shapefile. Note that grid cells
 #'                  are also generated for holes in the shapefile's polygon(s).
@@ -819,36 +712,26 @@ dgsavegrid <- function(grid,shpfname) {
 #'
 #' @param shpfname  File name of the shapefile. Filename should end with '.shp'
 #'
-#' @param frame     If TRUE, return a data frame suitable for ggplot plotting.
-#'                  If FALSE, return an OGR poly object
-#'
-#' @param wrapcells Cells which cross -180/180 degrees can present 
-#'                  difficulties for plotting. Setting this TRUE will result in
-#'                  cells with components in both hemispheres to be mapped
-#'                  entirely to positive degrees (the Eastern hemisphere). As a
-#'                  result, such cells will have components in the range
-#'                  [180,360). Only used when \code{frame=TRUE}.
-#'
 #' @param cellsize  Distance, in degrees, between the sample points used to
 #'                  generate the grid. Small values yield long generation times
 #'                  while large values may omit cells.
 #'
-#' @param savegrid  If savegrid is set to a file path, then a shapefile 
+#' @param savegrid  If savegrid is set to a file path, then a shapefile
 #'                  containing the grid is written to that path and the filename
 #'                  is returned. No other manipulations are done.
 #'                  Default: NA (do not save grid, return it)
 #'
-#' @return Returns a data frame or OGR poly object, as specified by \code{frame}.
+#' @return Returns an sf object.
 #'         If \code{!is.na(savegrid)}, returns a filename.
 #'
-#' @examples 
+#' @examples
 #' library(dggridR)
 #'
 #' dggs <- dgconstruct(spacing=25, metric=FALSE, resround='nearest')
 #' south_africa_grid <- dgshptogrid(dggs,dg_shpfname_south_africa())
 #' @export
-dgshptogrid <- function(dggs,shpfname,cellsize=0.1,frame=TRUE,wrapcells=TRUE,savegrid=NA){ #TODO: Densify?
-  dgverify(dggs) 
+dgshptogrid <- function(dggs,shpfname,cellsize=0.1,savegrid=NA){ #TODO: Densify?
+  dgverify(dggs)
 
   shpfname <- trimws(shpfname)
 
@@ -859,13 +742,13 @@ dgshptogrid <- function(dggs,shpfname,cellsize=0.1,frame=TRUE,wrapcells=TRUE,sav
 
   dsn   <- dirname(shpfname)
   layer <- tools::file_path_sans_ext(basename(shpfname))
-  poly  <- readOGR(dsn=dsn, layer=layer)
+  poly  <- sf::st_read(dsn, layer=layer)
 
   #Generate a dense grid of points
-  samp_points <- sp::makegrid(poly, cellsize = cellsize)
+  samp_points <- sp::makegrid(sf::as_Spatial(poly), cellsize = cellsize)
 
   #Convert the points to SEQNUM ids for dggs
   samp_points <- dgGEO_to_SEQNUM(dggs,samp_points$x1, samp_points$x2)$seqnum
 
-  dgcellstogrid(dggs, samp_points, frame=frame, wrapcells=wrapcells, savegrid=savegrid)
+  dgcellstogrid(dggs, samp_points, savegrid=savegrid)
 }
