@@ -1,6 +1,11 @@
+#ifndef DGGRIDR
+#define DGGRIDR
+#endif
 /* determine latitude angle phi-2 */
+#ifndef lint
+//static const char SCCSID[]="@(#)pj_phi2.c	4.3	93/06/12	GIE	REL";
+#endif
 #include "proj4.h"
-#include <cmath>
 
 #define TOL 1.0e-10
 #define N_ITER 15
@@ -11,14 +16,14 @@ pj_phi2(long double ts, long double e) {
 	int i;
 
 	eccnth = .5 * e;
-	Phi = projM_PI_2 - 2. * std::atan (ts);
+	Phi = M_PI_2 - 2. * atan (ts);
 	i = N_ITER;
 	do {
-		con = e * std::sin (Phi);
-		dphi = projM_PI_2 - 2. * std::atan (ts * std::pow((1. - con) /
+		con = e * sin (Phi);
+		dphi = M_PI_2 - 2. * atan (ts * pow((1. - con) /
 		   (1. + con), eccnth)) - Phi;
 		Phi += dphi;
-	} while ( std::fabs(dphi) > TOL && --i);
+	} while ( fabsl(dphi) > TOL && --i);
 /*
 	if (i <= 0)
 		pj_errno = -18;
